"""The active commands module.

These commands are used in the following models:
AWG5200, AWG70KA, AWG70KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - ACTive:MODE {NORMal|CALibration|DIAGnostic}
    - ACTive:MODE?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class ActiveMode(SCPICmdWrite, SCPICmdRead):
    """The ``ACTive:MODE`` command.

    Description:
        - This command enables and disables access to diagnostics or calibration. When the active
          mode is DIAGnostic or CALibration, all other non-diagnostic and non-calibration commands
          are ignored and no action occurs. If a test or procedure is in progress, errors are not
          returned; they are added to the system error queue, which can be accessed with
          ``SYSTEM:ERROR:NEXT``. For example: -200, '[D|C] are still running;' -300,'Device-specific
          error; Diagnostics tests still in progress - ``act:mode`` diag' -300,'Device-specific
          error; Calibration procedures still in progress - ``act:mode`` cal' To avoid this error,
          use the command ``DIAGNOSTIC:STOP:STATE`` or ``CALIBRATION:STOP:STATE`` to test for this
          condition. This command blocks when changing any state. Changing the state to NORMal
          causes a hardware initialization process and any related system settings are restored. If
          any diagnostic tests are in progress, then the request to change the active mode fails and
          the mode will not change. When changing the active mode, it's recommended to follow the
          action with an operation complete command (``*OPC``) to ensure the command has finished
          before other commands are processed.

    Usage:
        - Using the ``.query()`` method will send the ``ACTive:MODE?`` query.
        - Using the ``.verify(value)`` method will send the ``ACTive:MODE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACTive:MODE value`` command.

    SCPI Syntax:
        ```
        - ACTive:MODE {NORMal|CALibration|DIAGnostic}
        - ACTive:MODE?
        ```

    Info:
        - ``NORMal`` disables any active state for either calibration or diagnostics. When entering
          the active state of normal, the hardware is set to a default state and the previous system
          state is restored and waveform playout is set to off.
        - ``CALibration`` enables the active state for the calibration. Entering the active state of
          calibration turns waveform playout off.
        - ``DIAGnostic`` enables the active state for the diagnostics. Entering the active state of
          diagnostics turns waveform playout off.
        - ``*RST`` sets this to NORM.
    """


class Active(SCPICmdRead):
    """The ``ACTive`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``ACTive?`` query.
        - Using the ``.verify(value)`` method will send the ``ACTive?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.mode``: The ``ACTive:MODE`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "ACTive") -> None:
        super().__init__(device, cmd_syntax)
        self._mode = ActiveMode(device, f"{self._cmd_syntax}:MODE")

    @property
    def mode(self) -> ActiveMode:
        """Return the ``ACTive:MODE`` command.

        Description:
            - This command enables and disables access to diagnostics or calibration. When the
              active mode is DIAGnostic or CALibration, all other non-diagnostic and non-calibration
              commands are ignored and no action occurs. If a test or procedure is in progress,
              errors are not returned; they are added to the system error queue, which can be
              accessed with ``SYSTEM:ERROR:NEXT``. For example: -200, '[D|C] are still running;'
              -300,'Device-specific error; Diagnostics tests still in progress - ``act:mode`` diag'
              -300,'Device-specific error; Calibration procedures still in progress - ``act:mode``
              cal' To avoid this error, use the command ``DIAGNOSTIC:STOP:STATE`` or
              ``CALIBRATION:STOP:STATE`` to test for this condition. This command blocks when
              changing any state. Changing the state to NORMal causes a hardware initialization
              process and any related system settings are restored. If any diagnostic tests are in
              progress, then the request to change the active mode fails and the mode will not
              change. When changing the active mode, it's recommended to follow the action with an
              operation complete command (``*OPC``) to ensure the command has finished before other
              commands are processed.

        Usage:
            - Using the ``.query()`` method will send the ``ACTive:MODE?`` query.
            - Using the ``.verify(value)`` method will send the ``ACTive:MODE?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACTive:MODE value`` command.

        SCPI Syntax:
            ```
            - ACTive:MODE {NORMal|CALibration|DIAGnostic}
            - ACTive:MODE?
            ```

        Info:
            - ``NORMal`` disables any active state for either calibration or diagnostics. When
              entering the active state of normal, the hardware is set to a default state and the
              previous system state is restored and waveform playout is set to off.
            - ``CALibration`` enables the active state for the calibration. Entering the active
              state of calibration turns waveform playout off.
            - ``DIAGnostic`` enables the active state for the diagnostics. Entering the active state
              of diagnostics turns waveform playout off.
            - ``*RST`` sets this to NORM.
        """
        return self._mode



# pylint: disable=line-too-long
"""The diagnostic commands module.

These commands are used in the following models:
AWG5K, AWG5KC, AWG7K, AWG7KC

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - DIAGnostic:DATA?
    - DIAGnostic:IMMediate
    - DIAGnostic:IMMediate?
    - DIAGnostic:SELect {ALL|FPANel|AREGister|DTIMing|A1Memory|A2Memory|A3Memory|A4Memory|CREGister|CPLock|O1Register|O1ALevel|O1MLevel|O2Register|O2ALevel|O2MLevel}
    - DIAGnostic:SELect?
    ```
"""  # noqa: E501

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class DiagnosticSelect(SCPICmdWrite, SCPICmdRead):
    """The ``DIAGnostic:SELect`` command.

    Description:
        - This command selects the self-test routines. The query form of this command returns the
          selected test routine. The following selections are available: ALL FPANel - Front panel
          read/write access test DTIMing - Data timing measurement (for AWG5000 series only)
          AREGister - AWG register read back A1Memory - CH1 waveform memory test A2Memory - CH2
          waveform memory test A3Memory - CH3 waveform memory test (for AWG5000 series only)
          A4Memory - CH4 Waveform memory test (for AWG5000 series only) CREGister - Clock register
          read back CPLock - PLL Lock/unlock O1Register - Output1 register read back O1ALevel -
          Output1 analog level O1MLevel - Output1 Marker level (for AWG7000 series only) O2Register
          - Output2 register read back O2ALevel - Output2 analog level O2MLevel - Output2 marker
          level (for AWG7000 series only)

    Usage:
        - Using the ``.query()`` method will send the ``DIAGnostic:SELect?`` query.
        - Using the ``.verify(value)`` method will send the ``DIAGnostic:SELect?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``DIAGnostic:SELect value`` command.

    SCPI Syntax:
        ```
        - DIAGnostic:SELect {ALL|FPANel|AREGister|DTIMing|A1Memory|A2Memory|A3Memory|A4Memory|CREGister|CPLock|O1Register|O1ALevel|O1MLevel|O2Register|O2ALevel|O2MLevel}
        - DIAGnostic:SELect?
        ```
    """  # noqa: E501


class DiagnosticImmediate(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``DIAGnostic:IMMediate`` command.

    Description:
        - This command executes all of the NORMal diagnostic tests. The query form of this command
          executes all of the NORMal diagnostics and returns the results in the form of numeric of
          values of 0 for no errors or -330 for one or more tests failed. This changes the active
          mode to DIAGnostic, if necessary, and returns back to the original active mode when done.
          This makes a single pass of all of the NORMal diagnostics.

    Usage:
        - Using the ``.query()`` method will send the ``DIAGnostic:IMMediate?`` query.
        - Using the ``.verify(value)`` method will send the ``DIAGnostic:IMMediate?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write()`` method will send the ``DIAGnostic:IMMediate`` command.

    SCPI Syntax:
        ```
        - DIAGnostic:IMMediate
        - DIAGnostic:IMMediate?
        ```
    """


class DiagnosticData(SCPICmdRead):
    """The ``DIAGnostic:DATA`` command.

    Description:
        - This command returns the results of last executed tests for the NORMal diagnostic type in
          the form of a numeric value of 0 for no errors or -330 for one or more tests failed.
          Additional error details can be found by using the subsystem, area, and test queries such
          as ``DIAGnostic:RESult?`` <subsystem>[,<area>[,<test>]].

    Usage:
        - Using the ``.query()`` method will send the ``DIAGnostic:DATA?`` query.
        - Using the ``.verify(value)`` method will send the ``DIAGnostic:DATA?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - DIAGnostic:DATA?
        ```
    """


class Diagnostic(SCPICmdRead):
    """The ``DIAGnostic`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``DIAGnostic?`` query.
        - Using the ``.verify(value)`` method will send the ``DIAGnostic?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.data``: The ``DIAGnostic:DATA`` command.
        - ``.select``: The ``DIAGnostic:SELect`` command.
        - ``.immediate``: The ``DIAGnostic:IMMediate`` command.
    """

    def __init__(
        self, device: Optional["PIControl"] = None, cmd_syntax: str = "DIAGnostic"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._data = DiagnosticData(device, f"{self._cmd_syntax}:DATA")
        self._select = DiagnosticSelect(device, f"{self._cmd_syntax}:SELect")
        self._immediate = DiagnosticImmediate(device, f"{self._cmd_syntax}:IMMediate")

    @property
    def data(self) -> DiagnosticData:
        """Return the ``DIAGnostic:DATA`` command.

        Description:
            - This command returns the results of last executed tests for the NORMal diagnostic type
              in the form of a numeric value of 0 for no errors or -330 for one or more tests
              failed. Additional error details can be found by using the subsystem, area, and test
              queries such as ``DIAGnostic:RESult?`` <subsystem>[,<area>[,<test>]].

        Usage:
            - Using the ``.query()`` method will send the ``DIAGnostic:DATA?`` query.
            - Using the ``.verify(value)`` method will send the ``DIAGnostic:DATA?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - DIAGnostic:DATA?
            ```
        """
        return self._data

    @property
    def select(self) -> DiagnosticSelect:
        """Return the ``DIAGnostic:SELect`` command.

        Description:
            - This command selects the self-test routines. The query form of this command returns
              the selected test routine. The following selections are available: ALL FPANel - Front
              panel read/write access test DTIMing - Data timing measurement (for AWG5000 series
              only) AREGister - AWG register read back A1Memory - CH1 waveform memory test A2Memory
              - CH2 waveform memory test A3Memory - CH3 waveform memory test (for AWG5000 series
              only) A4Memory - CH4 Waveform memory test (for AWG5000 series only) CREGister - Clock
              register read back CPLock - PLL Lock/unlock O1Register - Output1 register read back
              O1ALevel - Output1 analog level O1MLevel - Output1 Marker level (for AWG7000 series
              only) O2Register - Output2 register read back O2ALevel - Output2 analog level O2MLevel
              - Output2 marker level (for AWG7000 series only)

        Usage:
            - Using the ``.query()`` method will send the ``DIAGnostic:SELect?`` query.
            - Using the ``.verify(value)`` method will send the ``DIAGnostic:SELect?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``DIAGnostic:SELect value`` command.

        SCPI Syntax:
            ```
            - DIAGnostic:SELect {ALL|FPANel|AREGister|DTIMing|A1Memory|A2Memory|A3Memory|A4Memory|CREGister|CPLock|O1Register|O1ALevel|O1MLevel|O2Register|O2ALevel|O2MLevel}
            - DIAGnostic:SELect?
            ```
        """  # noqa: E501
        return self._select

    @property
    def immediate(self) -> DiagnosticImmediate:
        """Return the ``DIAGnostic:IMMediate`` command.

        Description:
            - This command executes all of the NORMal diagnostic tests. The query form of this
              command executes all of the NORMal diagnostics and returns the results in the form of
              numeric of values of 0 for no errors or -330 for one or more tests failed. This
              changes the active mode to DIAGnostic, if necessary, and returns back to the original
              active mode when done. This makes a single pass of all of the NORMal diagnostics.

        Usage:
            - Using the ``.query()`` method will send the ``DIAGnostic:IMMediate?`` query.
            - Using the ``.verify(value)`` method will send the ``DIAGnostic:IMMediate?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write()`` method will send the ``DIAGnostic:IMMediate`` command.

        SCPI Syntax:
            ```
            - DIAGnostic:IMMediate
            - DIAGnostic:IMMediate?
            ```
        """
        return self._immediate



"""The counter commands module.

These commands are used in the following models:
DPO5K, DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO7K, DPO7KC, DSA70KC, DSA70KD, MSO5K, MSO5KB, MSO70KC,
MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - COUnter:RESULTs:AVGmean?
    - COUnter:RESULTs:DEViation?
    - COUnter:RESULTs:MAXimum?
    - COUnter:RESULTs:MINimum?
    - COUnter:RESULTs:NUMber?
    - COUnter:RESULTs:VALue?
    - COUnter:RESULTs?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class CounterResultsValue(SCPICmdRead):
    """The ``COUnter:RESULTs:VALue`` command.

    Description:
        - Queries the measured value obtained from the Trigger Source Frequency or A-B Trigger Time
          Interval Applications. The measured quantity is value.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs:VALue?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:VALue?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs:VALue?
        ```
    """


class CounterResultsNumber(SCPICmdRead):
    """The ``COUnter:RESULTs:NUMber`` command.

    Description:
        - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger Time
          Interval Applications. The value is the number of acquisitions (NUMber) taken at the time
          the command was given.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs:NUMber?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:NUMber?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs:NUMber?
        ```
    """


class CounterResultsMinimum(SCPICmdRead):
    """The ``COUnter:RESULTs:MINimum`` command.

    Description:
        - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger Time
          Interval Applications. The minimum is a statistical value accumulated over the number of
          acquisitions ('NUMber') taken at the time the command was given.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs:MINimum?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:MINimum?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs:MINimum?
        ```
    """


class CounterResultsMaximum(SCPICmdRead):
    """The ``COUnter:RESULTs:MAXimum`` command.

    Description:
        - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger Time
          Interval Applications. The maximum is a statistical value accumulated over the number of
          acquisitions (NUMber) taken at the time the command was given.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs:MAXimum?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:MAXimum?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs:MAXimum?
        ```
    """


class CounterResultsDeviation(SCPICmdRead):
    """The ``COUnter:RESULTs:DEViation`` command.

    Description:
        - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger Time
          Interval Applications. The Deviation is a statistical value accumulated over the number of
          acquisitions (NUMber) taken at the time the command was given.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs:DEViation?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:DEViation?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs:DEViation?
        ```
    """


class CounterResultsAvgmean(SCPICmdRead):
    """The ``COUnter:RESULTs:AVGmean`` command.

    Description:
        - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger Time
          Interval Applications. The AVGmean is a statistical value accumulated over the number of
          acquisitions (NUMber) taken at the time the command was given.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs:AVGmean?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:AVGmean?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs:AVGmean?
        ```
    """


class CounterResults(SCPICmdRead):
    """The ``COUnter:RESULTs`` command.

    Description:
        - Queries the measured and derived values obtained from the Trigger Source Frequency or A-B
          Trigger Time Interval Applications. The measured quantity is value. The minimum, maximum,
          AVGmean, and Deviation are statistical values accumulated over the number of acquisitions
          (NUMber) taken at the time the command is given. All results are returned with the single
          query ``COUnter:RESULTs?`` Individual results are returned by other queries

    Usage:
        - Using the ``.query()`` method will send the ``COUnter:RESULTs?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - COUnter:RESULTs?
        ```

    Properties:
        - ``.avgmean``: The ``COUnter:RESULTs:AVGmean`` command.
        - ``.deviation``: The ``COUnter:RESULTs:DEViation`` command.
        - ``.maximum``: The ``COUnter:RESULTs:MAXimum`` command.
        - ``.minimum``: The ``COUnter:RESULTs:MINimum`` command.
        - ``.number``: The ``COUnter:RESULTs:NUMber`` command.
        - ``.value``: The ``COUnter:RESULTs:VALue`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._avgmean = CounterResultsAvgmean(device, f"{self._cmd_syntax}:AVGmean")
        self._deviation = CounterResultsDeviation(device, f"{self._cmd_syntax}:DEViation")
        self._maximum = CounterResultsMaximum(device, f"{self._cmd_syntax}:MAXimum")
        self._minimum = CounterResultsMinimum(device, f"{self._cmd_syntax}:MINimum")
        self._number = CounterResultsNumber(device, f"{self._cmd_syntax}:NUMber")
        self._value = CounterResultsValue(device, f"{self._cmd_syntax}:VALue")

    @property
    def avgmean(self) -> CounterResultsAvgmean:
        """Return the ``COUnter:RESULTs:AVGmean`` command.

        Description:
            - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger
              Time Interval Applications. The AVGmean is a statistical value accumulated over the
              number of acquisitions (NUMber) taken at the time the command was given.

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs:AVGmean?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:AVGmean?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs:AVGmean?
            ```
        """
        return self._avgmean

    @property
    def deviation(self) -> CounterResultsDeviation:
        """Return the ``COUnter:RESULTs:DEViation`` command.

        Description:
            - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger
              Time Interval Applications. The Deviation is a statistical value accumulated over the
              number of acquisitions (NUMber) taken at the time the command was given.

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs:DEViation?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:DEViation?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs:DEViation?
            ```
        """
        return self._deviation

    @property
    def maximum(self) -> CounterResultsMaximum:
        """Return the ``COUnter:RESULTs:MAXimum`` command.

        Description:
            - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger
              Time Interval Applications. The maximum is a statistical value accumulated over the
              number of acquisitions (NUMber) taken at the time the command was given.

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs:MAXimum?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:MAXimum?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs:MAXimum?
            ```
        """
        return self._maximum

    @property
    def minimum(self) -> CounterResultsMinimum:
        """Return the ``COUnter:RESULTs:MINimum`` command.

        Description:
            - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger
              Time Interval Applications. The minimum is a statistical value accumulated over the
              number of acquisitions ('NUMber') taken at the time the command was given.

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs:MINimum?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:MINimum?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs:MINimum?
            ```
        """
        return self._minimum

    @property
    def number(self) -> CounterResultsNumber:
        """Return the ``COUnter:RESULTs:NUMber`` command.

        Description:
            - Queries the derived value obtained from the Trigger Source Frequency or A-B Trigger
              Time Interval Applications. The value is the number of acquisitions (NUMber) taken at
              the time the command was given.

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs:NUMber?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:NUMber?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs:NUMber?
            ```
        """
        return self._number

    @property
    def value(self) -> CounterResultsValue:
        """Return the ``COUnter:RESULTs:VALue`` command.

        Description:
            - Queries the measured value obtained from the Trigger Source Frequency or A-B Trigger
              Time Interval Applications. The measured quantity is value.

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs:VALue?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs:VALue?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs:VALue?
            ```
        """
        return self._value


class Counter(SCPICmdRead):
    """The ``COUnter`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``COUnter?`` query.
        - Using the ``.verify(value)`` method will send the ``COUnter?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.results``: The ``COUnter:RESULTs`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "COUnter") -> None:
        super().__init__(device, cmd_syntax)
        self._results = CounterResults(device, f"{self._cmd_syntax}:RESULTs")

    @property
    def results(self) -> CounterResults:
        """Return the ``COUnter:RESULTs`` command.

        Description:
            - Queries the measured and derived values obtained from the Trigger Source Frequency or
              A-B Trigger Time Interval Applications. The measured quantity is value. The minimum,
              maximum, AVGmean, and Deviation are statistical values accumulated over the number of
              acquisitions (NUMber) taken at the time the command is given. All results are returned
              with the single query ``COUnter:RESULTs?`` Individual results are returned by other
              queries

        Usage:
            - Using the ``.query()`` method will send the ``COUnter:RESULTs?`` query.
            - Using the ``.verify(value)`` method will send the ``COUnter:RESULTs?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - COUnter:RESULTs?
            ```

        Sub-properties:
            - ``.avgmean``: The ``COUnter:RESULTs:AVGmean`` command.
            - ``.deviation``: The ``COUnter:RESULTs:DEViation`` command.
            - ``.maximum``: The ``COUnter:RESULTs:MAXimum`` command.
            - ``.minimum``: The ``COUnter:RESULTs:MINimum`` command.
            - ``.number``: The ``COUnter:RESULTs:NUMber`` command.
            - ``.value``: The ``COUnter:RESULTs:VALue`` command.
        """
        return self._results



"""The acquire commands module.

These commands are used in the following models:
DPO2K, DPO2KB, MSO2K, MSO2KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - ACQuire:MAGnivu {ON|OFF|<NR1>}
    - ACQuire:MAGnivu?
    - ACQuire:MAXSamplerate?
    - ACQuire:MODe {SAMple|AVErage}
    - ACQuire:MODe?
    - ACQuire:NUMACq?
    - ACQuire:NUMAVg <NR1>
    - ACQuire:NUMAVg?
    - ACQuire:STATE {OFF|ON|RUN|STOP|<NR1>}
    - ACQuire:STATE?
    - ACQuire:STOPAfter {RUNSTop|SEQuence}
    - ACQuire:STOPAfter?
    - ACQuire?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class AcquireStopafter(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:STOPAfter`` command.

    Description:
        - This command sets or queries whether the instrument continually acquires acquisitions or
          acquires a single sequence. Pressing SINGLE on the front panel button is equivalent to
          sending these commands: ``ACQUIRE:STOPAFTER SEQUENCE`` and ``ACQUIRE:STATE 1``.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:STOPAfter?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:STOPAfter?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:STOPAfter value`` command.

    SCPI Syntax:
        ```
        - ACQuire:STOPAfter {RUNSTop|SEQuence}
        - ACQuire:STOPAfter?
        ```

    Info:
        - ``RUNSTop`` specifies that the instrument will continually acquire data, if
          ``ACQuire:STATE`` is turned on.
        - ``SEQuence`` specifies that the next acquisition will be a single-sequence acquisition.
    """


class AcquireState(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:STATE`` command.

    Description:
        - Starts or stops acquisitions. When state is set to ON or RUN, a new acquisition will be
          started. If the last acquisition was a single acquisition sequence, a new single sequence
          acquisition will be started. If the last acquisition was continuous, a new continuous
          acquisition will be started. If RUN is issued in the process of completing a single
          sequence acquisition (for example, averaging or enveloping), the acquisition sequence is
          restarted, and any accumulated data is discarded. Also, the oscilloscope resets the number
          of acquisitions. If the RUN argument is issued while in continuous mode, acquisition
          continues.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:STATE?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:STATE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:STATE value`` command.

    SCPI Syntax:
        ```
        - ACQuire:STATE {OFF|ON|RUN|STOP|<NR1>}
        - ACQuire:STATE?
        ```

    Info:
        - ``OFF`` stops acquisitions.
        - ``STOP`` stops acquisitions.
        - ``ON`` starts acquisitions.
        - ``RUN`` starts acquisitions.
        - ``<NR1>`` = 0 stops acquisitions; any other value starts acquisitions.
    """


class AcquireNumavg(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:NUMAVg`` command.

    Description:
        - This command sets or queries the number of waveform acquisitions that make up an averaged
          waveform. Ranges from 2 to 10240.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:NUMAVg?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMAVg?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:NUMAVg value`` command.

    SCPI Syntax:
        ```
        - ACQuire:NUMAVg <NR1>
        - ACQuire:NUMAVg?
        ```

    Info:
        - ``<NR1>`` is the number of waveform acquisitions to average.
    """


class AcquireNumacq(SCPICmdRead):
    """The ``ACQuire:NUMACq`` command.

    Description:
        - This query-only command returns the number of waveform acquisitions that have occurred
          since the last time acquisitions were stopped.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:NUMACq?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:NUMACq?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ACQuire:NUMACq?
        ```
    """


class AcquireMode(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:MODe`` command.

    Description:
        - Sets or returns the acquisition mode of the oscilloscope for all live waveforms. Waveforms
          are the displayed data point values taken from acquisition intervals. Each acquisition
          interval represents a time duration set by the horizontal scale (time per division). The
          oscilloscope sampling system always samples at the maximum rate, so the acquisition
          interval may include than one sample. The acquisition mode (which you set using this
          ``ACQuire:MODe`` command) determines how the final value of the acquisition interval is
          generated from the many data samples.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:MODe?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:MODe?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:MODe value`` command.

    SCPI Syntax:
        ```
        - ACQuire:MODe {SAMple|AVErage}
        - ACQuire:MODe?
        ```

    Info:
        - ``SAMple`` specifies that the displayed data point value is the first sampled value that
          is taken during the acquisition interval. In sample mode, all waveform data has 8 bits of
          precision. You can request 16 bit data with a CURVE query but the lower-order 8 bits of
          data will be zero. SAMple is the default mode.
        - ``AVErage`` specifies averaging mode, in which the resulting waveform shows an average of
          SAMple data points from several separate waveform acquisitions. The oscilloscope processes
          the number of waveforms you specify into the acquired waveform, creating a running
          exponential average of the input signal. The number of waveform acquisitions that go into
          making up the average waveform is set or queried using the ``ACQuire:NUMAVg`` command.
    """


class AcquireMaxsamplerate(SCPICmdRead):
    """The ``ACQuire:MAXSamplerate`` command.

    Description:
        - This query returns the maximum real-time sample rate.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:MAXSamplerate?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:MAXSamplerate?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ACQuire:MAXSamplerate?
        ```
    """


class AcquireMagnivu(SCPICmdWrite, SCPICmdRead):
    """The ``ACQuire:MAGnivu`` command.

    Description:
        - Turns on the MagniVu feature, which provides up to 32 times signal detail for fast viewing
          of short events. This feature is not recommended for slow data formats such as RS-232.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire:MAGnivu?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire:MAGnivu?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``ACQuire:MAGnivu value`` command.

    SCPI Syntax:
        ```
        - ACQuire:MAGnivu {ON|OFF|<NR1>}
        - ACQuire:MAGnivu?
        ```

    Info:
        - ``<NR1> = 0`` disables the MagniVu feature; any other value turns this feature on.
        - ``ON`` enables the MagniVu feature.
        - ``OFF`` disables the MagniVu feature.
    """


class Acquire(SCPICmdRead):
    """The ``ACQuire`` command.

    Description:
        - Queries the current acquisition state.

    Usage:
        - Using the ``.query()`` method will send the ``ACQuire?`` query.
        - Using the ``.verify(value)`` method will send the ``ACQuire?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - ACQuire?
        ```

    Properties:
        - ``.magnivu``: The ``ACQuire:MAGnivu`` command.
        - ``.maxsamplerate``: The ``ACQuire:MAXSamplerate`` command.
        - ``.mode``: The ``ACQuire:MODe`` command.
        - ``.numacq``: The ``ACQuire:NUMACq`` command.
        - ``.numavg``: The ``ACQuire:NUMAVg`` command.
        - ``.state``: The ``ACQuire:STATE`` command.
        - ``.stopafter``: The ``ACQuire:STOPAfter`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "ACQuire") -> None:
        super().__init__(device, cmd_syntax)
        self._magnivu = AcquireMagnivu(device, f"{self._cmd_syntax}:MAGnivu")
        self._maxsamplerate = AcquireMaxsamplerate(device, f"{self._cmd_syntax}:MAXSamplerate")
        self._mode = AcquireMode(device, f"{self._cmd_syntax}:MODe")
        self._numacq = AcquireNumacq(device, f"{self._cmd_syntax}:NUMACq")
        self._numavg = AcquireNumavg(device, f"{self._cmd_syntax}:NUMAVg")
        self._state = AcquireState(device, f"{self._cmd_syntax}:STATE")
        self._stopafter = AcquireStopafter(device, f"{self._cmd_syntax}:STOPAfter")

    @property
    def magnivu(self) -> AcquireMagnivu:
        """Return the ``ACQuire:MAGnivu`` command.

        Description:
            - Turns on the MagniVu feature, which provides up to 32 times signal detail for fast
              viewing of short events. This feature is not recommended for slow data formats such as
              RS-232.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:MAGnivu?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:MAGnivu?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:MAGnivu value`` command.

        SCPI Syntax:
            ```
            - ACQuire:MAGnivu {ON|OFF|<NR1>}
            - ACQuire:MAGnivu?
            ```

        Info:
            - ``<NR1> = 0`` disables the MagniVu feature; any other value turns this feature on.
            - ``ON`` enables the MagniVu feature.
            - ``OFF`` disables the MagniVu feature.
        """
        return self._magnivu

    @property
    def maxsamplerate(self) -> AcquireMaxsamplerate:
        """Return the ``ACQuire:MAXSamplerate`` command.

        Description:
            - This query returns the maximum real-time sample rate.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:MAXSamplerate?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:MAXSamplerate?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - ACQuire:MAXSamplerate?
            ```
        """
        return self._maxsamplerate

    @property
    def mode(self) -> AcquireMode:
        """Return the ``ACQuire:MODe`` command.

        Description:
            - Sets or returns the acquisition mode of the oscilloscope for all live waveforms.
              Waveforms are the displayed data point values taken from acquisition intervals. Each
              acquisition interval represents a time duration set by the horizontal scale (time per
              division). The oscilloscope sampling system always samples at the maximum rate, so the
              acquisition interval may include than one sample. The acquisition mode (which you set
              using this ``ACQuire:MODe`` command) determines how the final value of the acquisition
              interval is generated from the many data samples.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:MODe?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:MODe?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:MODe value`` command.

        SCPI Syntax:
            ```
            - ACQuire:MODe {SAMple|AVErage}
            - ACQuire:MODe?
            ```

        Info:
            - ``SAMple`` specifies that the displayed data point value is the first sampled value
              that is taken during the acquisition interval. In sample mode, all waveform data has 8
              bits of precision. You can request 16 bit data with a CURVE query but the lower-order
              8 bits of data will be zero. SAMple is the default mode.
            - ``AVErage`` specifies averaging mode, in which the resulting waveform shows an average
              of SAMple data points from several separate waveform acquisitions. The oscilloscope
              processes the number of waveforms you specify into the acquired waveform, creating a
              running exponential average of the input signal. The number of waveform acquisitions
              that go into making up the average waveform is set or queried using the
              ``ACQuire:NUMAVg`` command.
        """
        return self._mode

    @property
    def numacq(self) -> AcquireNumacq:
        """Return the ``ACQuire:NUMACq`` command.

        Description:
            - This query-only command returns the number of waveform acquisitions that have occurred
              since the last time acquisitions were stopped.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:NUMACq?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMACq?`` query and raise
              an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - ACQuire:NUMACq?
            ```
        """
        return self._numacq

    @property
    def numavg(self) -> AcquireNumavg:
        """Return the ``ACQuire:NUMAVg`` command.

        Description:
            - This command sets or queries the number of waveform acquisitions that make up an
              averaged waveform. Ranges from 2 to 10240.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:NUMAVg?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:NUMAVg?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:NUMAVg value`` command.

        SCPI Syntax:
            ```
            - ACQuire:NUMAVg <NR1>
            - ACQuire:NUMAVg?
            ```

        Info:
            - ``<NR1>`` is the number of waveform acquisitions to average.
        """
        return self._numavg

    @property
    def state(self) -> AcquireState:
        """Return the ``ACQuire:STATE`` command.

        Description:
            - Starts or stops acquisitions. When state is set to ON or RUN, a new acquisition will
              be started. If the last acquisition was a single acquisition sequence, a new single
              sequence acquisition will be started. If the last acquisition was continuous, a new
              continuous acquisition will be started. If RUN is issued in the process of completing
              a single sequence acquisition (for example, averaging or enveloping), the acquisition
              sequence is restarted, and any accumulated data is discarded. Also, the oscilloscope
              resets the number of acquisitions. If the RUN argument is issued while in continuous
              mode, acquisition continues.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:STATE?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:STATE?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:STATE value`` command.

        SCPI Syntax:
            ```
            - ACQuire:STATE {OFF|ON|RUN|STOP|<NR1>}
            - ACQuire:STATE?
            ```

        Info:
            - ``OFF`` stops acquisitions.
            - ``STOP`` stops acquisitions.
            - ``ON`` starts acquisitions.
            - ``RUN`` starts acquisitions.
            - ``<NR1>`` = 0 stops acquisitions; any other value starts acquisitions.
        """
        return self._state

    @property
    def stopafter(self) -> AcquireStopafter:
        """Return the ``ACQuire:STOPAfter`` command.

        Description:
            - This command sets or queries whether the instrument continually acquires acquisitions
              or acquires a single sequence. Pressing SINGLE on the front panel button is equivalent
              to sending these commands: ``ACQUIRE:STOPAFTER SEQUENCE`` and ``ACQUIRE:STATE 1``.

        Usage:
            - Using the ``.query()`` method will send the ``ACQuire:STOPAfter?`` query.
            - Using the ``.verify(value)`` method will send the ``ACQuire:STOPAfter?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``ACQuire:STOPAfter value`` command.

        SCPI Syntax:
            ```
            - ACQuire:STOPAfter {RUNSTop|SEQuence}
            - ACQuire:STOPAfter?
            ```

        Info:
            - ``RUNSTop`` specifies that the instrument will continually acquire data, if
              ``ACQuire:STATE`` is turned on.
            - ``SEQuence`` specifies that the next acquisition will be a single-sequence
              acquisition.
        """
        return self._stopafter



"""The reboot commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - REBOOT
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class Reboot(SCPICmdWriteNoArguments):
    """The ``REBOOT`` command.

    Description:
        - Reboots the system after a short delay, emulating the front panel power button push. The
          system will power back on after a 5 second delay.

    Usage:
        - Using the ``.write()`` method will send the ``REBOOT`` command.

    SCPI Syntax:
        ```
        - REBOOT
        ```
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "REBOOT") -> None:
        super().__init__(device, cmd_syntax)



"""The event commands module.

These commands are used in the following models:
AWG5K, AWG5KC, AWG7K, AWG7KC

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - EVENt:IMMediate
    - EVENt:IMPedance <ohms>
    - EVENt:IMPedance?
    - EVENt:JTIMing <jump_type>
    - EVENt:JTIMing?
    - EVENt:LEVel <level>
    - EVENt:LEVel?
    - EVENt:POLarity {POSitive|NEGative}
    - EVENt:POLarity?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class EventPolarity(SCPICmdWrite, SCPICmdRead):
    """The ``EVENt:POLarity`` command.

    Description:
        - This command and query sets or returns the polarity of event signal. The Event Jump is the
          function to change the sequencing of the waveform by an event signal.

    Usage:
        - Using the ``.query()`` method will send the ``EVENt:POLarity?`` query.
        - Using the ``.verify(value)`` method will send the ``EVENt:POLarity?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EVENt:POLarity value`` command.

    SCPI Syntax:
        ```
        - EVENt:POLarity {POSitive|NEGative}
        - EVENt:POLarity?
        ```

    Info:
        - ``POSitive`` indicates that event jump occurs when the instrument receives a positive
          pulse.
        - ``NEGative`` indicates that event jump occurs when the instrument receives a negative
          pulse.
    """


class EventLevel(SCPICmdWrite, SCPICmdRead):
    """The ``EVENt:LEVel`` command.

    Description:
        - This command and query sets or returns the event level.

    Usage:
        - Using the ``.query()`` method will send the ``EVENt:LEVel?`` query.
        - Using the ``.verify(value)`` method will send the ``EVENt:LEVel?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EVENt:LEVel value`` command.

    SCPI Syntax:
        ```
        - EVENt:LEVel <level>
        - EVENt:LEVel?
        ```

    Info:
        - ``<level>`` ::=<NR3>.
    """


class EventJtiming(SCPICmdWrite, SCPICmdRead):
    r"""The ``EVENt:JTIMing`` command.

    Description:
        - This command and query sets or returns the jump timing. Refer to the User Online Help for
          more information on jump timing.

    Usage:
        - Using the ``.query()`` method will send the ``EVENt:JTIMing?`` query.
        - Using the ``.verify(value)`` method will send the ``EVENt:JTIMing?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EVENt:JTIMing value`` command.

    SCPI Syntax:
        ```
        - EVENt:JTIMing <jump_type>
        - EVENt:JTIMing?
        ```

    Info:
        - ``<jump_type>`` ::={SYNChronous\|ASYNchronous}.
        - ``SYNChronous`` indicates jump occurs immediately.
        - ``ASYNchronous`` indicates jump occurs after the signal generation is finished.
    """


class EventImpedance(SCPICmdWrite, SCPICmdRead):
    """The ``EVENt:IMPedance`` command.

    Description:
        - This command and query sets or returns the impedance of the external event input. Valid
          values are 50 ohm or 1 kohm.

    Usage:
        - Using the ``.query()`` method will send the ``EVENt:IMPedance?`` query.
        - Using the ``.verify(value)`` method will send the ``EVENt:IMPedance?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``EVENt:IMPedance value`` command.

    SCPI Syntax:
        ```
        - EVENt:IMPedance <ohms>
        - EVENt:IMPedance?
        ```

    Info:
        - ``<ohms>`` ::=<NR3>.
    """


class EventImmediate(SCPICmdWriteNoArguments):
    """The ``EVENt:IMMediate`` command.

    Description:
        - This command generates a forced event. This is used to generate the event when the
          sequence is waiting for an event jump (See ``SEQUENCE:ELEMENTN:JTARGET:TYPE``). This is
          equivalent to pressing the Force Event button on the front panel of the instrument.

    Usage:
        - Using the ``.write()`` method will send the ``EVENt:IMMediate`` command.

    SCPI Syntax:
        ```
        - EVENt:IMMediate
        ```
    """


class Event(SCPICmdRead):
    """The ``EVENt`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``EVENt?`` query.
        - Using the ``.verify(value)`` method will send the ``EVENt?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.impedance``: The ``EVENt:IMPedance`` command.
        - ``.jtiming``: The ``EVENt:JTIMing`` command.
        - ``.level``: The ``EVENt:LEVel`` command.
        - ``.polarity``: The ``EVENt:POLarity`` command.
        - ``.immediate``: The ``EVENt:IMMediate`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "EVENt") -> None:
        super().__init__(device, cmd_syntax)
        self._impedance = EventImpedance(device, f"{self._cmd_syntax}:IMPedance")
        self._jtiming = EventJtiming(device, f"{self._cmd_syntax}:JTIMing")
        self._level = EventLevel(device, f"{self._cmd_syntax}:LEVel")
        self._polarity = EventPolarity(device, f"{self._cmd_syntax}:POLarity")
        self._immediate = EventImmediate(device, f"{self._cmd_syntax}:IMMediate")

    @property
    def impedance(self) -> EventImpedance:
        """Return the ``EVENt:IMPedance`` command.

        Description:
            - This command and query sets or returns the impedance of the external event input.
              Valid values are 50 ohm or 1 kohm.

        Usage:
            - Using the ``.query()`` method will send the ``EVENt:IMPedance?`` query.
            - Using the ``.verify(value)`` method will send the ``EVENt:IMPedance?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EVENt:IMPedance value`` command.

        SCPI Syntax:
            ```
            - EVENt:IMPedance <ohms>
            - EVENt:IMPedance?
            ```

        Info:
            - ``<ohms>`` ::=<NR3>.
        """
        return self._impedance

    @property
    def jtiming(self) -> EventJtiming:
        r"""Return the ``EVENt:JTIMing`` command.

        Description:
            - This command and query sets or returns the jump timing. Refer to the User Online Help
              for more information on jump timing.

        Usage:
            - Using the ``.query()`` method will send the ``EVENt:JTIMing?`` query.
            - Using the ``.verify(value)`` method will send the ``EVENt:JTIMing?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EVENt:JTIMing value`` command.

        SCPI Syntax:
            ```
            - EVENt:JTIMing <jump_type>
            - EVENt:JTIMing?
            ```

        Info:
            - ``<jump_type>`` ::={SYNChronous\|ASYNchronous}.
            - ``SYNChronous`` indicates jump occurs immediately.
            - ``ASYNchronous`` indicates jump occurs after the signal generation is finished.
        """
        return self._jtiming

    @property
    def level(self) -> EventLevel:
        """Return the ``EVENt:LEVel`` command.

        Description:
            - This command and query sets or returns the event level.

        Usage:
            - Using the ``.query()`` method will send the ``EVENt:LEVel?`` query.
            - Using the ``.verify(value)`` method will send the ``EVENt:LEVel?`` query and raise an
              AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EVENt:LEVel value`` command.

        SCPI Syntax:
            ```
            - EVENt:LEVel <level>
            - EVENt:LEVel?
            ```

        Info:
            - ``<level>`` ::=<NR3>.
        """
        return self._level

    @property
    def polarity(self) -> EventPolarity:
        """Return the ``EVENt:POLarity`` command.

        Description:
            - This command and query sets or returns the polarity of event signal. The Event Jump is
              the function to change the sequencing of the waveform by an event signal.

        Usage:
            - Using the ``.query()`` method will send the ``EVENt:POLarity?`` query.
            - Using the ``.verify(value)`` method will send the ``EVENt:POLarity?`` query and raise
              an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``EVENt:POLarity value`` command.

        SCPI Syntax:
            ```
            - EVENt:POLarity {POSitive|NEGative}
            - EVENt:POLarity?
            ```

        Info:
            - ``POSitive`` indicates that event jump occurs when the instrument receives a positive
              pulse.
            - ``NEGative`` indicates that event jump occurs when the instrument receives a negative
              pulse.
        """
        return self._polarity

    @property
    def immediate(self) -> EventImmediate:
        """Return the ``EVENt:IMMediate`` command.

        Description:
            - This command generates a forced event. This is used to generate the event when the
              sequence is waiting for an event jump (See ``SEQUENCE:ELEMENTN:JTARGET:TYPE``). This
              is equivalent to pressing the Force Event button on the front panel of the instrument.

        Usage:
            - Using the ``.write()`` method will send the ``EVENt:IMMediate`` command.

        SCPI Syntax:
            ```
            - EVENt:IMMediate
            ```
        """
        return self._immediate



"""The saveonevent commands module.

These commands are used in the following models:
MSO2

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - SAVEONEVent:FILEDest <Qstring>
    - SAVEONEVent:FILEDest?
    - SAVEONEVent:FILEName <QString>
    - SAVEONEVent:FILEName?
    - SAVEONEVent:IMAGe:FILEFormat {PNG|BMP|JPG}
    - SAVEONEVent:IMAGe:FILEFormat?
    - SAVEONEVent:WAVEform:FILEFormat {INTERNal|SPREADSheet|MATlab}
    - SAVEONEVent:WAVEform:FILEFormat?
    - SAVEONEVent:WAVEform:SOUrce {CH<x>|DCH<x>_D<x>|MATH<x>|REF<x>|ALL}
    - SAVEONEVent:WAVEform:SOUrce?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class SaveoneventWaveformSource(SCPICmdWrite, SCPICmdRead):
    """The ``SAVEONEVent:WAVEform:SOUrce`` command.

    Description:
        - This command sets or returns the sources for saving waveforms when an event occurs. This
          command replaces ``SAVEON:WAVEFORM:SOURCE`` (still valid command, but only an alias for
          this new command).

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:WAVEform:SOUrce?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:WAVEform:SOUrce?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVEONEVent:WAVEform:SOUrce value``
          command.

    SCPI Syntax:
        ```
        - SAVEONEVent:WAVEform:SOUrce {CH<x>|DCH<x>_D<x>|MATH<x>|REF<x>|ALL}
        - SAVEONEVent:WAVEform:SOUrce?
        ```

    Info:
        - ``CH<x>`` specifies an analog channel as the source waveform for saving.
        - ``DCH<x>_D<x>`` specifies a digital channel to use as the save on source. The supported
          digital channel value is 1. The supported digital bit values are 0 to 15 or DALL (all
          digital channels).
        - ``Math<x>`` specifies a math waveform as the source waveform for saving.
        - ``REF<x>`` specifies a reference waveform as the source waveform for saving.
        - ``ALL`` specifies all analog, math, digital, and reference waveforms as the source
          waveforms for saving.
    """


class SaveoneventWaveformFileformat(SCPICmdWrite, SCPICmdRead):
    """The ``SAVEONEVent:WAVEform:FILEFormat`` command.

    Description:
        - This command sets or returns the file extension (csv, wfm, mat). This command replaces
          ``SAVEON:WAVEFORM:FILEFORMAT`` (still valid command, but only an alias for this new
          command).

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:WAVEform:FILEFormat?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:WAVEform:FILEFormat?``
          query and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVEONEVent:WAVEform:FILEFormat value``
          command.

    SCPI Syntax:
        ```
        - SAVEONEVent:WAVEform:FILEFormat {INTERNal|SPREADSheet|MATlab}
        - SAVEONEVent:WAVEform:FILEFormat?
        ```

    Info:
        - ``INTERNal`` specifies saving the waveform in the instrument internal format.
        - ``SPREADSheet`` specifies saving the waveform in comma separated values format.
        - ``MATlab`` specifies saving the waveform in matlab compatible file format.
    """


class SaveoneventWaveform(SCPICmdRead):
    """The ``SAVEONEVent:WAVEform`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:WAVEform?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:WAVEform?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.fileformat``: The ``SAVEONEVent:WAVEform:FILEFormat`` command.
        - ``.source``: The ``SAVEONEVent:WAVEform:SOUrce`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._fileformat = SaveoneventWaveformFileformat(device, f"{self._cmd_syntax}:FILEFormat")
        self._source = SaveoneventWaveformSource(device, f"{self._cmd_syntax}:SOUrce")

    @property
    def fileformat(self) -> SaveoneventWaveformFileformat:
        """Return the ``SAVEONEVent:WAVEform:FILEFormat`` command.

        Description:
            - This command sets or returns the file extension (csv, wfm, mat). This command replaces
              ``SAVEON:WAVEFORM:FILEFORMAT`` (still valid command, but only an alias for this new
              command).

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:WAVEform:FILEFormat?``
              query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:WAVEform:FILEFormat?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``SAVEONEVent:WAVEform:FILEFormat value`` command.

        SCPI Syntax:
            ```
            - SAVEONEVent:WAVEform:FILEFormat {INTERNal|SPREADSheet|MATlab}
            - SAVEONEVent:WAVEform:FILEFormat?
            ```

        Info:
            - ``INTERNal`` specifies saving the waveform in the instrument internal format.
            - ``SPREADSheet`` specifies saving the waveform in comma separated values format.
            - ``MATlab`` specifies saving the waveform in matlab compatible file format.
        """
        return self._fileformat

    @property
    def source(self) -> SaveoneventWaveformSource:
        """Return the ``SAVEONEVent:WAVEform:SOUrce`` command.

        Description:
            - This command sets or returns the sources for saving waveforms when an event occurs.
              This command replaces ``SAVEON:WAVEFORM:SOURCE`` (still valid command, but only an
              alias for this new command).

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:WAVEform:SOUrce?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:WAVEform:SOUrce?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVEONEVent:WAVEform:SOUrce value``
              command.

        SCPI Syntax:
            ```
            - SAVEONEVent:WAVEform:SOUrce {CH<x>|DCH<x>_D<x>|MATH<x>|REF<x>|ALL}
            - SAVEONEVent:WAVEform:SOUrce?
            ```

        Info:
            - ``CH<x>`` specifies an analog channel as the source waveform for saving.
            - ``DCH<x>_D<x>`` specifies a digital channel to use as the save on source. The
              supported digital channel value is 1. The supported digital bit values are 0 to 15 or
              DALL (all digital channels).
            - ``Math<x>`` specifies a math waveform as the source waveform for saving.
            - ``REF<x>`` specifies a reference waveform as the source waveform for saving.
            - ``ALL`` specifies all analog, math, digital, and reference waveforms as the source
              waveforms for saving.
        """
        return self._source


class SaveoneventImageFileformat(SCPICmdWrite, SCPICmdRead):
    """The ``SAVEONEVent:IMAGe:FILEFormat`` command.

    Description:
        - This command sets or returns the image file extension (png, jpg, bmp). This command
          replaces ``SAVEON:IMAGE:FILEFORMAT`` (still valid command, but only an alias for this new
          command).

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:IMAGe:FILEFormat?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:IMAGe:FILEFormat?`` query
          and raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVEONEVent:IMAGe:FILEFormat value``
          command.

    SCPI Syntax:
        ```
        - SAVEONEVent:IMAGe:FILEFormat {PNG|BMP|JPG}
        - SAVEONEVent:IMAGe:FILEFormat?
        ```

    Info:
        - ``PNG`` specifies using PNG format for saved image files.
        - ``BMP`` specifies using BMP format for saved image files.
        - ``JPG`` specifies using JPEG format for saved image files.
    """


class SaveoneventImage(SCPICmdRead):
    """The ``SAVEONEVent:IMAGe`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:IMAGe?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:IMAGe?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.fileformat``: The ``SAVEONEVent:IMAGe:FILEFormat`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._fileformat = SaveoneventImageFileformat(device, f"{self._cmd_syntax}:FILEFormat")

    @property
    def fileformat(self) -> SaveoneventImageFileformat:
        """Return the ``SAVEONEVent:IMAGe:FILEFormat`` command.

        Description:
            - This command sets or returns the image file extension (png, jpg, bmp). This command
              replaces ``SAVEON:IMAGE:FILEFORMAT`` (still valid command, but only an alias for this
              new command).

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:IMAGe:FILEFormat?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:IMAGe:FILEFormat?``
              query and raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the
              ``SAVEONEVent:IMAGe:FILEFormat value`` command.

        SCPI Syntax:
            ```
            - SAVEONEVent:IMAGe:FILEFormat {PNG|BMP|JPG}
            - SAVEONEVent:IMAGe:FILEFormat?
            ```

        Info:
            - ``PNG`` specifies using PNG format for saved image files.
            - ``BMP`` specifies using BMP format for saved image files.
            - ``JPG`` specifies using JPEG format for saved image files.
        """
        return self._fileformat


class SaveoneventFilename(SCPICmdWrite, SCPICmdRead):
    """The ``SAVEONEVent:FILEName`` command.

    Description:
        - This command sets or queries the file name without the extension. This command replaces
          ``SAVEON:FILE:NAME`` (still valid command, but only an alias for this new command).

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:FILEName?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:FILEName?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVEONEVent:FILEName value`` command.

    SCPI Syntax:
        ```
        - SAVEONEVent:FILEName <QString>
        - SAVEONEVent:FILEName?
        ```

    Info:
        - ``<QString>`` specifies the name of the file.
    """

    _WRAP_ARG_WITH_QUOTES = True


class SaveoneventFiledest(SCPICmdWrite, SCPICmdRead):
    """The ``SAVEONEVent:FILEDest`` command.

    Description:
        - This command sets or queries the location where files are saved. This command replaces
          ``SAVEON:FILE:DEST`` (still valid command, but only an alias for this new command).

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent:FILEDest?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent:FILEDest?`` query and
          raise an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SAVEONEVent:FILEDest value`` command.

    SCPI Syntax:
        ```
        - SAVEONEVent:FILEDest <Qstring>
        - SAVEONEVent:FILEDest?
        ```

    Info:
        - ``<QString>`` specifies the location to store files.
    """


class Saveonevent(SCPICmdRead):
    """The ``SAVEONEVent`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``SAVEONEVent?`` query.
        - Using the ``.verify(value)`` method will send the ``SAVEONEVent?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.filedest``: The ``SAVEONEVent:FILEDest`` command.
        - ``.filename``: The ``SAVEONEVent:FILEName`` command.
        - ``.image``: The ``SAVEONEVent:IMAGe`` command tree.
        - ``.waveform``: The ``SAVEONEVent:WAVEform`` command tree.
    """

    def __init__(
        self, device: Optional["PIControl"] = None, cmd_syntax: str = "SAVEONEVent"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._filedest = SaveoneventFiledest(device, f"{self._cmd_syntax}:FILEDest")
        self._filename = SaveoneventFilename(device, f"{self._cmd_syntax}:FILEName")
        self._image = SaveoneventImage(device, f"{self._cmd_syntax}:IMAGe")
        self._waveform = SaveoneventWaveform(device, f"{self._cmd_syntax}:WAVEform")

    @property
    def filedest(self) -> SaveoneventFiledest:
        """Return the ``SAVEONEVent:FILEDest`` command.

        Description:
            - This command sets or queries the location where files are saved. This command replaces
              ``SAVEON:FILE:DEST`` (still valid command, but only an alias for this new command).

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:FILEDest?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:FILEDest?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVEONEVent:FILEDest value``
              command.

        SCPI Syntax:
            ```
            - SAVEONEVent:FILEDest <Qstring>
            - SAVEONEVent:FILEDest?
            ```

        Info:
            - ``<QString>`` specifies the location to store files.
        """
        return self._filedest

    @property
    def filename(self) -> SaveoneventFilename:
        """Return the ``SAVEONEVent:FILEName`` command.

        Description:
            - This command sets or queries the file name without the extension. This command
              replaces ``SAVEON:FILE:NAME`` (still valid command, but only an alias for this new
              command).

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:FILEName?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:FILEName?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SAVEONEVent:FILEName value``
              command.

        SCPI Syntax:
            ```
            - SAVEONEVent:FILEName <QString>
            - SAVEONEVent:FILEName?
            ```

        Info:
            - ``<QString>`` specifies the name of the file.
        """
        return self._filename

    @property
    def image(self) -> SaveoneventImage:
        """Return the ``SAVEONEVent:IMAGe`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:IMAGe?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:IMAGe?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.fileformat``: The ``SAVEONEVent:IMAGe:FILEFormat`` command.
        """
        return self._image

    @property
    def waveform(self) -> SaveoneventWaveform:
        """Return the ``SAVEONEVent:WAVEform`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``SAVEONEVent:WAVEform?`` query.
            - Using the ``.verify(value)`` method will send the ``SAVEONEVent:WAVEform?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.fileformat``: The ``SAVEONEVent:WAVEform:FILEFormat`` command.
            - ``.source``: The ``SAVEONEVent:WAVEform:SOUrce`` command.
        """
        return self._waveform



"""The synchronize commands module.

These commands are used in the following models:
AWG5200

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - SYNChronize:ADJust:STARt
    - SYNChronize:DESKew:ABORt
    - SYNChronize:DESKew:STARt
    - SYNChronize:DESKew:STATe?
    - SYNChronize:ENABle {ON|OFF|1|0}
    - SYNChronize:ENABle?
    - SYNChronize:TYPE {MASTer|SLAVe}
    - SYNChronize:TYPE?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class SynchronizeType(SCPICmdWrite, SCPICmdRead):
    """The ``SYNChronize:TYPE`` command.

    Description:
        - This command sets or returns the instrument type (master or slave) when synchronization is
          enabled.

    Usage:
        - Using the ``.query()`` method will send the ``SYNChronize:TYPE?`` query.
        - Using the ``.verify(value)`` method will send the ``SYNChronize:TYPE?`` query and raise an
          AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SYNChronize:TYPE value`` command.

    SCPI Syntax:
        ```
        - SYNChronize:TYPE {MASTer|SLAVe}
        - SYNChronize:TYPE?
        ```
    """


class SynchronizeEnable(SCPICmdWrite, SCPICmdRead):
    """The ``SYNChronize:ENABle`` command.

    Description:
        - This command enables or disables synchronization in the instrument.

    Usage:
        - Using the ``.query()`` method will send the ``SYNChronize:ENABle?`` query.
        - Using the ``.verify(value)`` method will send the ``SYNChronize:ENABle?`` query and raise
          an AssertionError if the returned value does not match ``value``.
        - Using the ``.write(value)`` method will send the ``SYNChronize:ENABle value`` command.

    SCPI Syntax:
        ```
        - SYNChronize:ENABle {ON|OFF|1|0}
        - SYNChronize:ENABle?
        ```
    """


class SynchronizeDeskewState(SCPICmdRead):
    """The ``SYNChronize:DESKew:STATe`` command.

    Description:
        - This command returns the state of the system deskew condition.

    Usage:
        - Using the ``.query()`` method will send the ``SYNChronize:DESKew:STATe?`` query.
        - Using the ``.verify(value)`` method will send the ``SYNChronize:DESKew:STATe?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - SYNChronize:DESKew:STATe?
        ```
    """


class SynchronizeDeskewStart(SCPICmdWriteNoArguments):
    """The ``SYNChronize:DESKew:STARt`` command.

    Description:
        - This command only performs a system deskew calibration.

    Usage:
        - Using the ``.write()`` method will send the ``SYNChronize:DESKew:STARt`` command.

    SCPI Syntax:
        ```
        - SYNChronize:DESKew:STARt
        ```
    """


class SynchronizeDeskewAbort(SCPICmdWriteNoArguments):
    """The ``SYNChronize:DESKew:ABORt`` command.

    Description:
        - This command cancels a system deskew calibration.

    Usage:
        - Using the ``.write()`` method will send the ``SYNChronize:DESKew:ABORt`` command.

    SCPI Syntax:
        ```
        - SYNChronize:DESKew:ABORt
        ```
    """


class SynchronizeDeskew(SCPICmdRead):
    """The ``SYNChronize:DESKew`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``SYNChronize:DESKew?`` query.
        - Using the ``.verify(value)`` method will send the ``SYNChronize:DESKew?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.abort``: The ``SYNChronize:DESKew:ABORt`` command.
        - ``.state``: The ``SYNChronize:DESKew:STATe`` command.
        - ``.start``: The ``SYNChronize:DESKew:STARt`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._abort = SynchronizeDeskewAbort(device, f"{self._cmd_syntax}:ABORt")
        self._state = SynchronizeDeskewState(device, f"{self._cmd_syntax}:STATe")
        self._start = SynchronizeDeskewStart(device, f"{self._cmd_syntax}:STARt")

    @property
    def abort(self) -> SynchronizeDeskewAbort:
        """Return the ``SYNChronize:DESKew:ABORt`` command.

        Description:
            - This command cancels a system deskew calibration.

        Usage:
            - Using the ``.write()`` method will send the ``SYNChronize:DESKew:ABORt`` command.

        SCPI Syntax:
            ```
            - SYNChronize:DESKew:ABORt
            ```
        """
        return self._abort

    @property
    def state(self) -> SynchronizeDeskewState:
        """Return the ``SYNChronize:DESKew:STATe`` command.

        Description:
            - This command returns the state of the system deskew condition.

        Usage:
            - Using the ``.query()`` method will send the ``SYNChronize:DESKew:STATe?`` query.
            - Using the ``.verify(value)`` method will send the ``SYNChronize:DESKew:STATe?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - SYNChronize:DESKew:STATe?
            ```
        """
        return self._state

    @property
    def start(self) -> SynchronizeDeskewStart:
        """Return the ``SYNChronize:DESKew:STARt`` command.

        Description:
            - This command only performs a system deskew calibration.

        Usage:
            - Using the ``.write()`` method will send the ``SYNChronize:DESKew:STARt`` command.

        SCPI Syntax:
            ```
            - SYNChronize:DESKew:STARt
            ```
        """
        return self._start


class SynchronizeAdjustStart(SCPICmdWriteNoArguments):
    """The ``SYNChronize:ADJust:STARt`` command.

    Description:
        - This command only performs a system sample rate calibration on the synchronized system.
          This command may take up to 3 minutes to complete.

    Usage:
        - Using the ``.write()`` method will send the ``SYNChronize:ADJust:STARt`` command.

    SCPI Syntax:
        ```
        - SYNChronize:ADJust:STARt
        ```
    """


class SynchronizeAdjust(SCPICmdRead):
    """The ``SYNChronize:ADJust`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``SYNChronize:ADJust?`` query.
        - Using the ``.verify(value)`` method will send the ``SYNChronize:ADJust?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.start``: The ``SYNChronize:ADJust:STARt`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._start = SynchronizeAdjustStart(device, f"{self._cmd_syntax}:STARt")

    @property
    def start(self) -> SynchronizeAdjustStart:
        """Return the ``SYNChronize:ADJust:STARt`` command.

        Description:
            - This command only performs a system sample rate calibration on the synchronized
              system. This command may take up to 3 minutes to complete.

        Usage:
            - Using the ``.write()`` method will send the ``SYNChronize:ADJust:STARt`` command.

        SCPI Syntax:
            ```
            - SYNChronize:ADJust:STARt
            ```
        """
        return self._start


class Synchronize(SCPICmdRead):
    """The ``SYNChronize`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``SYNChronize?`` query.
        - Using the ``.verify(value)`` method will send the ``SYNChronize?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.adjust``: The ``SYNChronize:ADJust`` command tree.
        - ``.deskew``: The ``SYNChronize:DESKew`` command tree.
        - ``.enable``: The ``SYNChronize:ENABle`` command.
        - ``.type``: The ``SYNChronize:TYPE`` command.
    """

    def __init__(
        self, device: Optional["PIControl"] = None, cmd_syntax: str = "SYNChronize"
    ) -> None:
        super().__init__(device, cmd_syntax)
        self._adjust = SynchronizeAdjust(device, f"{self._cmd_syntax}:ADJust")
        self._deskew = SynchronizeDeskew(device, f"{self._cmd_syntax}:DESKew")
        self._enable = SynchronizeEnable(device, f"{self._cmd_syntax}:ENABle")
        self._type = SynchronizeType(device, f"{self._cmd_syntax}:TYPE")

    @property
    def adjust(self) -> SynchronizeAdjust:
        """Return the ``SYNChronize:ADJust`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``SYNChronize:ADJust?`` query.
            - Using the ``.verify(value)`` method will send the ``SYNChronize:ADJust?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.start``: The ``SYNChronize:ADJust:STARt`` command.
        """
        return self._adjust

    @property
    def deskew(self) -> SynchronizeDeskew:
        """Return the ``SYNChronize:DESKew`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``SYNChronize:DESKew?`` query.
            - Using the ``.verify(value)`` method will send the ``SYNChronize:DESKew?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.abort``: The ``SYNChronize:DESKew:ABORt`` command.
            - ``.state``: The ``SYNChronize:DESKew:STATe`` command.
            - ``.start``: The ``SYNChronize:DESKew:STARt`` command.
        """
        return self._deskew

    @property
    def enable(self) -> SynchronizeEnable:
        """Return the ``SYNChronize:ENABle`` command.

        Description:
            - This command enables or disables synchronization in the instrument.

        Usage:
            - Using the ``.query()`` method will send the ``SYNChronize:ENABle?`` query.
            - Using the ``.verify(value)`` method will send the ``SYNChronize:ENABle?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SYNChronize:ENABle value`` command.

        SCPI Syntax:
            ```
            - SYNChronize:ENABle {ON|OFF|1|0}
            - SYNChronize:ENABle?
            ```
        """
        return self._enable

    @property
    def type(self) -> SynchronizeType:
        """Return the ``SYNChronize:TYPE`` command.

        Description:
            - This command sets or returns the instrument type (master or slave) when
              synchronization is enabled.

        Usage:
            - Using the ``.query()`` method will send the ``SYNChronize:TYPE?`` query.
            - Using the ``.verify(value)`` method will send the ``SYNChronize:TYPE?`` query and
              raise an AssertionError if the returned value does not match ``value``.
            - Using the ``.write(value)`` method will send the ``SYNChronize:TYPE value`` command.

        SCPI Syntax:
            ```
            - SYNChronize:TYPE {MASTer|SLAVe}
            - SYNChronize:TYPE?
            ```
        """
        return self._type
